package org.processmining.streamalphaminer.plugins;

import org.processmining.contexts.uitopia.UIPluginContext;
import org.processmining.contexts.uitopia.annotations.UITopiaVariant;
import org.processmining.eventstream.core.interfaces.XSEventStream;
import org.processmining.eventstream.readers.acceptingpetrinet.XSEventStreamToAcceptingPetriNetReader;
import org.processmining.framework.plugin.PluginContext;
import org.processmining.framework.plugin.annotations.Plugin;
import org.processmining.framework.plugin.annotations.PluginVariant;
import org.processmining.stream.core.enums.CommunicationType;
import org.processmining.streamabstractrepresentation.parameters.UnCoupledAbstractionSchemeParametersImpl;
import org.processmining.streamabstractrepresentation.plugins.AbstractUncoupledStreamMinerDefaultDialogsPlugin;
import org.processmining.streamalphaminer.algorithms.UncoupledStreamAlphaAPNXSEventReaderImpl;

@Plugin(name = "Discover Accepting Petri Net(s) (Alpha Miner)", parameterLabels = { "Event Stream",
		"Parameters" }, returnLabels = { "Alpha Miner (Event Stream)" }, returnTypes = {
				XSEventStreamToAcceptingPetriNetReader.class }, userAccessible = true)
public class StreamAlphaMinerAcceptingPetriNetPlugin extends
		AbstractUncoupledStreamMinerDefaultDialogsPlugin<XSEventStreamToAcceptingPetriNetReader, UnCoupledAbstractionSchemeParametersImpl> {

	@UITopiaVariant(author = "S.J. van Zelst", email = "s.j.v.zelst@tue.nl", affiliation = "Eindhoven University of Technology")
	@PluginVariant(requiredParameterLabels = { 0 })
	@Override
	public XSEventStreamToAcceptingPetriNetReader apply(final UIPluginContext context, final XSEventStream stream) {
		return super.apply(context, stream);
	}

	@UITopiaVariant(author = "S.J. van Zelst", email = "s.j.v.zelst@tue.nl", affiliation = "Eindhoven University of Technology", uiLabel = UITopiaVariant.USEVARIANT)
	@PluginVariant(variantLabel = "Discover Accepting Petri Net(s) (Alpha Miner, Default Parameters)", requiredParameterLabels = {
			0 })
	public XSEventStreamToAcceptingPetriNetReader applyDefault(final PluginContext context,
			final XSEventStream stream) {
		return super.apply(context, stream, getFreshParameters(context));
	}

	protected UnCoupledAbstractionSchemeParametersImpl getFreshParameters(PluginContext context) {
		return new UnCoupledAbstractionSchemeParametersImpl();
	}

	protected XSEventStreamToAcceptingPetriNetReader constructReader(PluginContext context, CommunicationType comm,
			UnCoupledAbstractionSchemeParametersImpl parameters) {
		return new UncoupledStreamAlphaAPNXSEventReaderImpl(context, parameters);
	}

}
